Skip to contents

ai_turns() gives the turns from the first to the head, in order (all = TRUE: every turn of every branch, in the order they were made), as a tibble: turn (its id, the call's id in the call log), parent, state ("running", "waiting", "interrupted", "done", "failed", "stopped", "abandoned"), inputs (a list column), answer (of the answer's type; NA for a turn not done), outputs (a list column), model. ai_turn() gives one turn, as an object for approve(), resume_turn(), stop_turn().

Usage

ai_turns(chat, all = FALSE)

ai_turn(chat, which = -1L)

Arguments

chat

A conversation.

all

Every turn of every branch.

which

A turn: its index in ai_turns(chat), its id (-1, the default: the head).

Value

A tibble (ai_turns()), or a turn.