1 when every output the answers have a value for equals the prediction's
(text compared ignoring case and repeated white space), else 0; with
several outputs, each also gets <name>_match.
1 when every output the answers have a value for equals the prediction's
(text compared ignoring case and repeated white space), else 0; with
several outputs, each also gets <name>_match.