Skip to contents

A program's input or output that takes any R value, a data frame, a model or a connection, unchecked. Its values are logged as JSON when they have a JSON form, and described otherwise ({"$type", "$repr"}). A program with one cannot be served or conversed with: only data crosses those.

Usage

opaque()

Value

A field.