ai_turns() gives the turns from the first to the head, in order (all = TRUE: every turn of every branch, in the order they were made), as a
tibble: turn (its id, the call's id in the call log), parent,
state ("running", "waiting", "interrupted", "done", "failed",
"stopped", "abandoned"), inputs (a list column), answer (of the
answer's type; NA for a turn not done), outputs (a list column),
model. ai_turn() gives one turn, as an object for
approve(), resume_turn(), stop_turn().